%define _buildid .0

%define aws_product_name_env  EC2_HOME
%define aws_product_name      ec2

Summary:   The API tools serve as the client interface to the Amazon EC2 web service. Use these tools to register and launch instances, manipulate security groups, and more. 
Name:      aws-apitools-%{aws_product_name}
Version:   1.7.3.0
Release: 1%{?_buildid}%{?dist}
License:   Amazon Software License
Group:     Amazon/Tools
# http://aws.amazon.com/developertools/351
URL:       http://aws.amazon.com/%{aws_product_name}
Source0:   https://ec2-downloads.s3.amazonaws.com/ec2-api-tools-%{version}.zip
BuildArch: noarch
Prefix:    /opt
Vendor:    Amazon AWS
Requires:  jre >= 1.6.0
Requires:  aws-apitools-common

%define aws_path              %{prefix}/aws
%define aws_bin_path          %{aws_path}/bin
%define aws_product_name_v    %{aws_product_name}-%{version}
%define aws_product_path      %{aws_path}/apitools/%{aws_product_name_v}
%define aws_product_path_link %{aws_path}/apitools/%{aws_product_name}

%description
Amazon Elastic Compute Cloud (Amazon EC2) is a web service that
provides resizable compute capacity in the cloud. It is designed to
make web-scale computing easier for developers.

Amazon EC2's simple web service interface allows you to obtain and
configure capacity with minimal friction. It provides you with
complete control of your computing resources and lets you run on
Amazon's proven computing environment. Amazon EC2 reduces the time
required to obtain and boot new server instances to minutes,
allowing you to quickly scale capacity, both up and down, as your
computing requirements change. Amazon EC2 changes the economics of
computing by allowing you to pay only for capacity that you
actually use. Amazon EC2 provides developers the tools to build
failure resilient applications and isolate themselves from common
failure scenarios.

%prep
%setup -q -n ec2-api-tools-%{version}

%build
#Released as jar files at this point, no need to build

# Make sure we don't install .cmd files
%__rm bin/*.cmd
%___build_post

%install
# Build installation directory structure
%__mkdir_p %{buildroot}/%{aws_product_path}
%__mkdir   %{buildroot}/%{aws_product_path}/bin
%__mkdir   %{buildroot}/%{aws_product_path}/lib
%__ln_s    %{aws_product_name_v} %{buildroot}/%{aws_product_path_link}

%__mkdir_p %{buildroot}/%{aws_bin_path}

# Install all scripts in bin directory
%__install -m 755 bin/* %{buildroot}/%{aws_product_path}/bin

# Install all text files:
%__install -m 644 *.txt  %{buildroot}/%{aws_product_path}/
%__install -m 644 *.TXT  %{buildroot}/%{aws_product_path}/

# Install Java libs
%__install -m 755 lib/* %{buildroot}/%{aws_product_path}/lib

# Create sym links
for i in %{buildroot}/%{aws_product_path}/bin/*; do
    %define command_name $(basename $i)
    %__ln_s %{aws_product_path}/bin/%{command_name} \
        %{buildroot}/%{aws_bin_path}/%{command_name}
done

# Build the environment script
echo "# Set %{aws_product_name_env}.  Called from /etc/profile.d/aws-product-common" > %{buildroot}/%{aws_product_path}/environment.sh
echo "[ -z \"\$%{aws_product_name_env}\" ] && %{aws_product_name_env}=\"%{aws_product_path_link}\"" >> %{buildroot}/%{aws_product_path}/environment.sh
echo "export %{aws_product_name_env}" >> %{buildroot}/%{aws_product_path}/environment.sh


%files
%doc %{aws_product_path}/*.txt
%doc %{aws_product_path}/*.TXT

%attr(0755,root,root) %dir %{aws_product_path}
%attr(0755,root,root) %dir %{aws_product_path}/lib

# Scripts installed with execute permission
%attr(0755,root,root) %dir %{aws_product_path}/bin
%attr(0755,root,root) %dir %{aws_bin_path}

# The sym links for easy access
%{aws_bin_path}/*
%{aws_product_path_link}

# Everything else
%{aws_product_path}/lib/*
%attr(0755,root,root) %{aws_product_path}/bin/*
%{aws_product_path}/environment.sh

%changelog
* Fri Jan 9 2015 Lee Trager <ltrager@amazon.com>
- Update to 1.7.3.0 from upstream

* Mon Dec 29 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.7.2.4 from upstream

* Tue Nov 25 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.7.2.3 from upstream

* Fri Nov 21 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.7.2.2 from upstream

* Fri Nov 14 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.7.2.0 from upstream

* Tue Nov 4 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.7.1.3 from upstream

* Tue Oct 28 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.7.1.2 from upstream

* Fri Sep 12 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.7.1.1 from upstream

* Wed Jul 2 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.7.1.0 from upstream

* Thu Jun 5 2014 Andrew Jorgensen <ajorgens@amazon.com>
- Use the full source URL
- Update to 1.7.0.2 from upstream
- Update to 1.7.0.1 from upstream

* Tue Jun 3 2014 hpetty <hpetty@amazon.com>
- Update to 1.7.0.0 from upstream

* Fri May 30 2014 hpetty <hpetty@amazon.com>
- Update to 1.6.14.1 from upstream

* Tue Apr 8 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.6.13.0 from upstream

* Mon Jan 27 2014 Lee Trager <ltrager@amazon.com>
- Update to 1.6.12.2 from upstream

* Thu Nov 14 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.12.0 from upstream

* Wed Oct 16 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.11.0 from upstream

* Thu Sep 26 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.10.1 from upstream

* Fri Sep 13 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.10.0 from upstream

* Tue Sep 10 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.9.0 from upstream

* Mon Aug 12 2013 Lee Trager <ltrager@amazon.com>
- Upgrade to 1.6.8.1 from upstream

* Wed Jul 10 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.8.0 from upstream

* Tue May 7 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.7.3 from upstream

* Wed Apr 10 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.7.2 from upstream

* Sat Mar 23 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.7.1 from upstream

* Tue Mar 12 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.7 from upstream

* Tue Feb 12 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.6.4

* Mon Jan 14 2013 Lee Trager <ltrager@amazon.com>
- Update to 1.6.6.0 from upstream

* Mon Nov 5 2012 Lee Trager <ltrager@amazon.com>
- Update to 1.6.5.1 from upstream

* Mon Sep 17 2012 Lee Trager <ltrager@amazon.com>
- Update to 1.6.3.0 from upstream

* Fri Sep 7 2012 Andrew Jorgensen <ajorgens@amazon.com>
- Update to 1.6.1.4 from upstream

* Wed Aug 22 2012 Ben Cressey <bcressey@amazon.com>
- Update to 1.6.1.4 from upstream

* Thu Aug 9 2012 Lee Trager <ltrager@amazon.com>
- Update to 1.6.1.2 from upstream

* Mon Jul 30 2012 Lee Trager <ltrager@amazon.com>
- Update to 1.6.1.0 from upstream

* Wed Jul 25 2012 Lee Trager <ltrager@amazon.com>
- Update to 1.6.0.0 from upstream.

* Thu Jul 12 2012 Lee Trager <ltrager@amazon.com>
- Upgrade to 1.5.6.0 from upstream

* Mon Jun 11 2012 Lee Trager <ltrager@amazon.com>
- Include missing license file
- Update to 1.5.5.0 from upstream

* Tue Jun 5 2012 Lee Trager <ltrager@amazon.com>
- Set the description, add aws-apitools-common as a dep, and set the package group to Amazon/Tools

* Sat Jun 2 2012 Lee Trager <ltrager@amazon.com>
- Cleanup the spec file and ship with the symlinks instead of creating them in the post install script
- Update to 1.5.4.0 from upstream

* Mon Apr 23 2012 Lee Trager <ltrager@amazon.com>
- Update to the latest version from upstream

* Wed Mar 14 2012 Andrew Jorgensen <ajorgens@amazon.com>
- Update to 1.5.2.5

* Tue Jan 3 2012 Andrew Jorgensen <ajorgens@amazon.com>
- Update to 1.5.2.2

* Thu Dec 22 2011 Andrew Jorgensen <ajorgens@amazon.com>
- Date removed from version string again
- Update to 1.5.1.0

* Fri Dec 9 2011 Andrew Jorgensen <ajorgens@amazon.com>
- Update to 1.5.0.1

* Mon Sep 19 2011 Andrew Jorgensen <ajorgens@amazon.com>
- Update to 1.4.4.2 and use upstream .zip

* Wed Jun 1 2011 Nathan Blackham <blackham@amazon.com>
- fix typo in version number

* Wed May 18 2011 Nathan Blackham <blackham@amazon.com>
- New version 1.4.2.4

* Thu Mar 24 2011 Nathan Blackham <blackham@amazon.com>
- update to 1.4.1.2

* Mon Feb 7 2011 Nathan Blackham <blackham@amazon.com>
- updating jre requires to >= 1.6.0

* Tue Dec 21 2010 Nathan Blackham <blackham@amazon.com>
- upgrading to 1.3.62308

* Wed Sep 22 2010 Nathan Blackham <blackham@amazon.com>
- fix typo
- upgrading to 1.3-57419

* Wed Jul 21 2010 Nathan Blackham <blackham@amazon.com>
- add dist tag

* Thu Jul 1 2010 Cristian Gafton <gafton@amazon.com>
- import source package tools/aws-apitools-ec2-1.3.46266-2
- setup complete for package aws-apitools-ec2

* Tue Apr 13 2010 KaOS <kaos@amazon.com>
- Requires: jre

* Thu Feb 25 2010 KaOS <kaos@amazon.com>
- 1.3.46266
- Initial packaging
